@@ -1,6 +1,7 @@
 from dianping.client import Client
 from dianping.request.oauth import AuthorizePlatformRequest
 from dianping.request.oauth import RefreshTokenRequest
+from dianping.request.oauth import DynamicTokenRequest
 
 
 def platformauthtest():
@@ -20,6 +21,16 @@ def refreshtokentest():
     assert (response is not None)
 
 
+def dynamicTokenRequest():
+    dynamicTokenRequest = DynamicTokenRequest('f9e039e3da9ea9ec', '6c8ac87e6f81a7c8249b12fd7efee4cf4dd7a787',
+                                              '19bbc883eb621a2604018805f7fb18b6f6c88340', 'cn.bing.com')
+    client = Client(dynamicTokenRequest)
+    response = client.invoke()
+    print(response)
+    assert (response is not None)
+
+
 if __name__ == '__main__':
     platformauthtest()
     refreshtokentest()
+    dynamicTokenRequest()
